
# q-expansion of newform 1143.2.a.j, downloaded from the LMFDB on 06 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1143
weight = 2
poly_data = [1, -24, 102, -66, -99, 59, 26, -14, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[-4, 0, 1, 0, 0, 0, 0, 0, 0], 1], [[0, -6, 0, 1, 0, 0, 0, 0, 0], 1], [[-7, -3, 99, 29, -70, -11, 15, 1, -1], 4], [[32, -170, 59, 157, -58, -40, 14, 3, -1], 6], [[-5, -337, 499, 401, -338, -113, 73, 9, -5], 12], [[-11, 80, -74, -89, 60, 25, -14, -2, 1], 2], [[-27, 251, -247, -247, 190, 65, -43, -5, 3], 4]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, -1], [-1, -1, 0, 0, 0, 0, 1, 0, 0], [2, 1, 0, 0, -1, -1, -1, -1, 0], [2, 0, 1, 0, 0, -1, -1, -1, -1], [0, 0, -1, 0, 0, 1, 1, 1, 1], [0, 0, 0, 0, 0, 0, 0, 2, 0], [3, -1, 1, -1, -1, -2, -1, -1, 1], [0, 0, -1, 0, 0, -1, 1, 1, 1], [4, -1, 2, -1, 0, 0, 0, -1, 0], [0, 0, -1, 1, 1, 0, 0, -1, -1], [0, -1, -1, -1, 0, 1, 1, 0, 1], [0, -2, -1, -1, 1, 1, 0, 1, -1], [3, -1, 1, -1, -1, -2, -1, 1, 1], [-2, 0, -2, 2, 2, 2, 2, 2, 0], [1, 0, 1, -2, -2, -1, -1, 1, 0], [2, -3, -1, 1, 2, 1, 1, 0, 1], [-5, -1, -2, 1, -1, 1, 2, 0, 0], [1, -2, -1, 1, 1, 2, 0, -1, 0], [2, -2, 1, 1, 1, 0, 0, 1, -1], [4, 2, 2, 0, 0, -2, 0, -2, 0], [4, -2, 0, 0, 2, 1, 0, 0, 0], [0, 0, 0, 2, 0, 2, 0, 0, 0], [2, 2, 0, 0, -2, -2, -2, -2, 0], [4, 0, 1, 1, -1, -4, -2, -1, 1], [-2, -2, -3, 0, 0, 0, 1, 1, 1], [2, -4, 0, 2, 0, 0, 0, 0, 2], [0, 0, -1, 1, -1, 0, 0, 1, 1], [-1, 0, 0, 0, 0, 0, 0, 0, 0], [4, -2, 2, -2, 0, -1, -4, -2, 0], [2, 0, 0, -2, 2, 2, 2, 2, 0], [2, -2, 0, 0, -2, 0, 0, -2, -2], [-2, 4, -3, 0, -2, 3, -1, 1, 1], [-1, 0, 0, 2, 2, -2, 0, 2, -3], [1, 2, 1, -1, -1, 0, 0, 1, 2], [0, 0, 0, 4, 0, 0, 4, 0, 0], [0, -4, 0, 2, 2, 2, 4, 0, 0], [10, -2, 4, -2, 0, -3, 0, -2, 2], [-8, 0, -1, 2, 0, 0, -1, -3, 1], [4, -2, 4, -2, 2, 0, 2, 0, 0], [0, -2, -2, -2, 2, -2, -2, 2, 0], [-4, -4, -4, 2, 2, 0, 2, 2, 2], [0, 0, -1, 1, -1, 0, 4, 1, 5], [2, -2, -1, -1, 1, -2, 0, 1, 3], [10, 4, -1, -1, -3, -2, -2, -3, 1], [0, -1, 3, -1, 2, -1, 3, 0, -1], [-7, 3, -1, -1, -1, -2, 1, 1, -1], [2, 2, -2, 2, 4, 0, 0, 4, 2], [2, 0, 0, 2, -2, -1, -2, -2, -2], [-4, 4, 0, -2, 2, 0, -4, -2, -4], [-2, 2, 0, 0, 2, 2, 2, 0, 0], [-2, -4, 3, -1, 1, -2, 0, -1, 1], [9, 7, 1, -3, -1, -2, -3, -1, 1], [3, 5, -2, -1, -1, -3, -2, 2, 0], [-2, -4, -1, 0, 2, 3, 5, 3, -1], [2, 4, 0, 0, 2, 2, 0, 2, -4], [0, -4, 4, 0, -2, -4, 0, 0, 0], [8, 0, 2, 0, 0, 1, 0, 2, 2], [3, 2, -2, 2, 0, 4, 2, 2, -1], [11, -5, 1, -1, -1, -2, -1, -1, 5], [-11, 2, -4, 2, 0, 4, 4, 4, 3], [0, 0, 2, 2, -2, 0, 2, 0, -2], [8, -4, 6, -4, 0, -8, -2, -2, 0], [4, 0, -2, -2, 2, 2, -2, 2, -4], [1, 6, 2, 0, 2, 0, -2, 0, -3], [0, 0, -2, -2, 2, 2, -2, -2, 0], [-6, 2, -4, -2, -6, 0, 0, -2, 0], [-4, 2, 0, -2, -2, 2, -2, 2, 0], [6, 0, 1, 0, 2, 3, 3, 1, 1], [10, 0, 4, -2, -6, -6, -6, -6, -2], [-4, 6, 1, 2, 0, 1, -1, 5, -1], [0, 2, 2, 0, 0, 0, -2, -6, -2], [12, 3, -1, 1, 2, -1, -1, -2, 1], [-1, -3, 1, 5, 1, 2, 3, -1, 1], [4, 4, 3, 1, -1, -4, 4, 1, 1], [-4, 4, -5, -2, 0, 3, 1, -1, 1], [8, -4, 4, -4, -4, -2, -2, -4, -2], [-10, 2, -10, 2, 2, 8, 6, 4, 0], [-18, 2, -5, 0, -4, 2, 3, 3, 3], [-8, 8, -4, 0, 0, 0, 0, 2, 2], [-4, 2, -1, -1, -3, -1, 0, 1, 7], [15, -4, 7, -6, -2, -5, -3, -5, -4], [4, -1, 1, -5, 2, 1, -3, 0, 1], [3, -5, 2, 1, -1, -3, -2, -4, 4], [10, -2, 3, 1, 1, -2, -2, -1, -5], [7, 2, 3, 1, -3, -4, -4, -5, -6], [5, -1, 3, 1, -5, -4, -1, -1, -1], [-2, -4, -3, 0, 0, 3, 7, 7, 5], [6, 6, -2, 6, 6, 4, 0, 0, -6], [2, 0, -3, 1, 5, 7, 2, 5, -5], [-8, 3, -5, -1, 0, -3, 1, 2, 5], [-14, 8, 0, 2, 2, 4, -2, -2, -2], [1, -6, -8, 4, 6, 6, 4, 6, 3], [-2, -4, -5, -1, 5, 10, 8, 7, 1], [2, 12, 0, -4, -4, -2, -4, 0, 0], [4, 0, 1, 4, 2, -3, -1, -3, 3], [2, 0, 3, 3, 1, -2, -2, -3, 1], [-2, 0, 4, 0, 0, -2, 0, 0, 0], [3, 0, 0, 0, 0, 0, 6, -2, 5], [-12, 4, -4, 0, -2, 0, -4, 2, 0], [2, 4, 6, -2, -4, -2, -4, -2, -2], [-2, 0, -3, -1, -1, -2, -4, -7, -1], [16, 5, -1, -3, 0, -3, 1, 2, 1], [4, 0, -5, -2, 0, 3, 1, 7, 1], [1, 3, 2, -3, -3, -1, 2, -2, 8], [5, -1, -3, 3, -3, -8, -1, -1, 1], [-8, 4, 10, -4, -6, -8, -4, -6, -4], [2, -2, -4, 0, -2, -2, 0, -2, 4], [2, -4, 5, -4, -4, -5, -5, -5, 1], [4, -2, 4, -2, -2, -4, -10, -2, -4], [-8, 8, -6, 2, -2, 5, -2, -2, 2], [-5, 6, -4, 4, -2, 0, 4, 6, 5], [-6, -1, 3, -5, -6, -3, -3, -4, 1], [-14, -4, 0, 4, 4, -1, 2, 2, -2], [6, 0, 1, 1, -3, -4, -6, 1, -3], [2, -2, -2, 2, 2, -2, -2, 4, 2], [-8, 4, -7, 3, 3, 4, 8, 5, -3], [-20, -2, -2, -2, 6, 2, 2, 4, 4], [-7, -2, 1, -1, -1, -4, 4, -3, 6], [-6, 3, 0, 3, -2, 2, 6, 3, 2], [4, 0, 4, -8, -2, -4, -4, 2, 4], [4, -4, 4, -2, 0, -2, -6, 2, 6], [2, 7, 5, -3, -6, -5, -1, -10, -3], [-1, 5, 5, -5, -5, 0, -1, -1, -1], [-4, 3, 0, 0, -5, 1, 1, -5, 0], [-12, 4, -5, -2, 4, 8, -1, 1, 1], [14, 9, 7, 1, -2, -7, -3, -8, 1], [-6, -1, -1, 5, 8, 13, 3, 8, -5], [-2, -14, 5, 1, 1, -8, 0, -3, -1], [0, 4, -6, -2, -2, 0, 4, -2, 2], [-2, 2, -2, -2, 0, 4, 0, 4, -8], [-3, 0, 1, 2, 6, -3, -1, -3, -4], [5, 3, -3, -3, -3, -6, 3, -1, 3], [6, 6, 2, -8, -2, -4, -4, 0, -2], [6, 0, -1, -4, -4, 1, 1, 1, 1], [-6, 6, 1, -3, -5, 0, 0, -1, -3], [8, 2, 2, 6, 4, 2, -2, 0, -8], [-8, 2, 3, 2, 0, -5, -3, -5, -5], [0, -2, 1, -3, 3, 4, 4, 3, -1], [0, -8, 4, -4, -4, 1, 2, -8, 0], [0, -12, 3, 0, 6, 1, 1, -9, -1], [-6, 0, 0, 0, 2, 8, 10, 0, 4], [16, -4, 0, 2, 4, -6, -4, -4, 4], [-8, -2, 2, 6, -2, -2, 6, 4, 0], [-4, 0, 2, 0, -8, -10, -8, -6, 4], [2, 4, 2, -4, -4, -2, 2, 0, 6], [-1, -16, -4, 2, 2, 2, 10, 4, 1], [4, -4, -2, 2, 4, 4, 6, 6, -4], [5, 0, 3, -2, 2, -1, -3, -1, -6], [3, 3, 5, -7, -5, -4, -1, -3, -1], [-4, 4, -5, -4, 0, -1, -3, 1, -3], [6, 6, 0, 4, 2, -10, 0, 2, 2], [6, -4, -5, 7, 5, 8, 2, 1, -3], [-24, 2, -2, 2, 4, 3, 4, 2, 8], [-2, -2, 9, -2, 0, 1, -5, -3, -7], [-1, 1, 3, 5, 1, 4, 3, 3, -3], [6, 6, -8, 2, 4, 2, 0, 6, 0], [-28, 2, -5, 1, 7, 4, 6, 5, -1], [10, 4, 0, -2, -4, -12, -8, -6, 0], [-6, 0, -9, 1, 3, 10, 0, 5, -1], [0, 11, 5, 3, -4, -5, -13, -10, -5], [-3, 3, 8, -4, -2, -2, 1, -2, 0], [-6, -6, -1, 1, 3, 4, -2, -3, -3], [6, -4, -1, -1, -5, -5, -6, -5, 1], [-7, -2, 2, 0, 6, 10, 2, 4, 1], [0, -10, 2, 0, -4, 0, 8, 0, 2], [3, -8, -1, 2, 2, 1, 1, -5, 4], [-18, -6, -5, 1, 9, 14, 10, 7, -1], [-14, 12, 2, 4, 6, 6, -2, -6, -6], [2, 4, 6, -6, -2, -6, -4, 4, -6], [18, -6, 7, 4, 2, -9, -3, -1, -1], [8, 5, -6, -2, -1, -5, 3, 7, -2], [-11, -6, -2, 2, 8, 12, 6, 10, -7], [-14, 8, -12, 2, -2, 7, 4, 10, 6], [-12, 4, -3, 0, 2, 13, 3, 5, -3], [-19, -1, 3, 3, 3, 2, -1, -3, 5], [-14, 6, -1, 2, -2, -1, -7, 5, -3], [10, -4, 4, -2, 2, 0, -6, -8, -4], [-14, 6, -7, -3, -3, 8, 4, 1, 7], [-6, 2, -8, 6, -4, -2, -4, -2, -2], [-18, 12, 0, -2, -8, -4, -4, -4, 2], [-36, 2, 1, -2, 0, 9, 7, 5, 5], [-9, -7, -4, -1, -1, -5, 8, 8, 2], [2, -6, -4, 4, 6, 13, 6, -2, 2], [16, -2, 4, -4, 2, -4, 2, 0, 2], [-10, 12, -3, 1, 5, 6, -2, -3, 1], [-2, 1, 10, 1, -6, -8, -12, -13, -8], [-3, 11, 3, -5, -5, -2, -3, -3, -5], [-6, 0, 0, -2, -2, -2, -6, 0, -8], [-4, 8, 4, 6, 6, 6, 0, 6, -8], [22, 11, 11, -1, -6, -7, -15, -12, 1], [2, 0, 1, -5, 1, 0, -12, -5, 1], [-8, -2, -1, -1, 1, 3, -4, -3, -9], [12, -12, 7, -3, 3, -8, -8, -3, -7], [-18, 6, 0, -2, -6, 0, -6, -6, -2], [3, -4, -1, 2, 2, -5, 5, -1, 0], [8, -4, -3, -4, 8, 5, -1, 7, -7], [20, -18, -6, 2, 8, 6, 6, 6, 6], [0, 0, 2, -4, 0, -3, -2, -6, -2], [-4, -6, -3, 1, 1, 4, 0, 5, 5], [-19, -4, 0, 0, -2, 8, 8, 4, 7], [20, -6, 0, 0, 0, -6, 4, -2, -8], [-12, 6, -6, 4, -4, 4, -4, -2, 0], [-26, -2, 0, 2, -4, -3, 2, 2, -2], [-16, -2, 3, -9, -5, 2, -4, -1, -1], [6, 4, 0, -4, -4, -1, -2, 6, 8], [6, 2, 5, -2, -2, 5, -1, -1, -7], [10, -22, 1, 2, 0, -3, -1, 1, 1], [-10, 4, 0, -2, 2, -2, 4, 8, 0], [-10, 0, 7, -4, 6, 1, -3, 3, -1], [-7, 0, 4, -6, 2, 6, -2, 4, 3], [-5, -7, -8, 3, -1, 3, 8, 0, -6], [14, 2, -1, 8, 8, 4, -1, -5, -5], [16, -6, -4, -2, 10, 10, -2, 0, 0], [12, 0, -2, -2, -2, 0, 0, 2, 6], [11, -1, 5, -1, -7, -2, -7, -3, -5], [-2, 20, -8, 0, -4, -2, -4, 0, -2], [2, 14, -5, -2, -2, 5, 1, 1, 3], [6, -4, 8, -4, 6, 4, 2, -6, -2], [-34, 6, -6, 6, 0, 4, 6, 4, -4], [33, 1, 11, -5, -9, -4, -9, -13, -5], [-24, -6, -6, -2, -6, -6, 2, 6, 8], [2, -4, -3, 1, 1, 1, -2, -3, 3], [-13, 14, 1, -1, 3, -6, 4, 5, -4], [18, -8, 7, 1, 5, 2, 8, 7, 5], [-24, -8, -3, 2, 4, 10, 5, 3, -5], [0, 0, -1, 0, 6, 1, 1, 3, -9], [10, 2, 0, -2, 2, 4, 0, -2, -4], [10, 4, 8, -6, 2, 2, -8, -4, -4], [20, 4, 9, 1, -7, -6, -10, -3, 3], [-18, 12, -3, 9, 7, 16, 2, 3, -9], [-22, -12, 1, 0, 4, -1, 3, -5, -1], [5, -12, 2, -4, 0, 0, -6, -14, 1], [22, 4, 2, -2, 4, 6, 6, -4, -2], [-30, 4, -14, 2, -2, 8, 8, 10, -2], [6, -6, 4, 6, 0, -5, -6, -2, -6], [-18, 10, 0, 2, -2, -4, -2, 6, -4], [16, 10, -2, 0, -8, 4, -4, -2, 0], [4, 2, -10, 4, 8, 10, 6, 10, 4], [16, 21, -1, -5, -4, -7, -3, -6, 3], [-14, 0, -12, 0, 2, 4, 0, -6, 0], [0, 14, 1, -1, -7, -6, -8, -7, 1], [18, 6, 4, -2, -8, -3, -2, -10, -6], [15, -13, 0, -4, 0, -4, 1, 8, 4], [7, 6, 4, 6, -4, -8, -10, -10, 5], [-15, 11, -5, 3, -5, -2, -7, 5, -5], [2, 8, 4, 0, 4, 6, -2, -6, -6], [-12, -10, -8, 6, 10, 8, 6, 8, 6], [6, 15, -1, -3, -8, -11, -9, 4, -1], [2, 0, -12, 10, 6, 2, 6, 2, 4], [6, 8, 2, -6, 0, 4, 0, -4, 2], [10, 12, 6, -8, -8, -6, -6, 6, 6], [-13, 15, -7, -3, -5, 4, -1, -1, -1], [-2, -6, -6, 4, 0, -2, 10, 10, 6], [10, -6, -8, 6, -2, 2, -6, 0, 2], [0, 2, -10, 2, 10, 10, 2, 6, -4], [12, -4, -5, 0, -2, -5, -3, -5, 1], [14, -4, -4, -4, 4, 2, 2, 4, 4], [11, -4, 8, -4, -4, 0, -6, -10, -3], [9, -1, 14, -2, -8, -10, -7, -12, 2], [-16, -25, 0, 7, 0, 2, 2, -3, -2], [-8, -2, -15, -1, 1, 10, 12, 17, 9], [20, -6, 6, 0, -2, 6, 6, -2, -4], [23, -2, 0, 2, -4, 0, 2, 6, 9], [0, 6, -8, -4, 2, 0, 0, 0, -10], [-2, 14, 7, -2, 6, 3, -3, -3, -13], [4, 12, -1, 4, -10, -5, -3, -5, 3], [-34, 0, -4, 8, -2, 2, 12, 6, 6], [-10, -4, 0, -2, -6, -6, 4, 4, 4], [-25, -2, -12, 6, 4, 0, 6, 6, -7], [6, 2, -2, 2, -6, 0, 0, -10, 4], [4, 9, -5, 1, 4, -3, -3, -8, 1], [-4, 6, 2, -2, 0, 6, 0, -6, 8], [-3, -2, -8, -8, -2, -2, -4, -6, 3], [-10, -8, -13, -5, 3, 5, 14, 19, 5], [22, 11, 10, -2, -5, -11, -7, -17, -6], [28, 0, 6, 2, 2, -12, 0, -4, 8], [0, 2, 8, -8, -4, -10, 4, -2, -6], [24, 2, 8, -4, -10, -6, -16, -14, 0], [2, 8, -4, 0, 0, 6, 6, 14, 2], [-10, 14, 13, 0, 4, 0, -7, -3, -7], [2, 2, -4, 0, 6, -2, -4, -2, -4], [14, -13, -1, -7, 0, -5, 7, 2, 1], [2, 0, -12, 10, 0, 0, 6, 4, 8], [-16, 2, -2, 8, 4, 14, 12, 0, 2], [-18, -2, 14, -10, 0, -4, -6, 0, -6], [18, -11, 5, 3, 2, -17, -5, 2, -7], [16, -12, -2, -2, -2, -5, 8, 6, 14], [0, -2, 2, 4, -6, -10, -2, -2, -4], [16, 8, 11, -6, 0, 2, 3, -3, 1], [12, 20, -11, 4, 4, -1, -5, 7, -3], [26, -2, -3, 4, 2, -11, -5, -3, 1], [2, -12, 2, -4, 2, 4, 6, 2, -4], [26, -8, -5, 0, -2, -3, 1, -5, 3], [4, 7, -17, -1, 0, 9, 5, 16, 1], [2, 8, 5, 0, -2, 1, 3, 5, -3], [6, 4, 7, -5, -11, -10, -4, -9, -3], [16, 4, 5, 0, -6, -9, -1, 1, -3], [28, 5, 4, 5, -8, -6, -10, -5, 2], [-12, 2, -10, -2, 0, -1, -4, -2, -2], [2, 8, 1, 4, -4, -3, -17, -5, -11], [-1, 7, 4, -3, -5, -9, 0, 10, -6], [31, 0, 8, 2, -2, -8, -4, 2, 1], [-20, 8, -14, 4, 8, 12, -2, 6, 4], [-6, 2, 3, -4, 6, 3, -3, -1, -5], [-7, -4, 4, -4, 2, 0, 12, -4, -1], [-20, 2, -8, 4, -2, -2, -8, -10, -4], [20, -8, 5, -2, -4, -11, -5, -3, -1], [4, -2, 10, -10, -4, -13, -4, -2, 0], [12, 14, 7, -7, -9, -8, -10, 1, 7], [-8, -8, 4, 0, -2, 10, 8, 10, 0], [26, -3, 5, -1, 0, -7, 9, 10, 3], [6, -2, 10, -2, -8, -10, -8, -6, -4], [-14, -8, -10, 8, 4, 14, 22, 10, 6], [-24, -12, 0, 2, -4, -8, 0, -12, 6], [-16, -4, -1, 2, 4, 16, -1, 9, -3], [9, -8, 0, 4, -2, 8, 0, -12, -1], [30, 4, 8, -6, -2, -2, -10, -6, 0], [22, -12, 1, 4, 2, -5, 3, 9, 7], [4, -2, 2, 6, 2, 4, 2, 0, -2], [-13, 5, -7, 17, 5, 6, 1, 1, -5], [19, -4, 8, -8, 0, -8, -14, -6, -3], [10, 0, -4, 4, 6, 0, -4, -2, -2], [14, 9, 6, 1, -10, -4, 4, -9, 8], [4, -4, -10, 2, -2, 4, 4, 6, 2], [10, 0, 7, -1, -5, -12, -6, -5, -5], [-16, 4, 0, 6, 0, 6, 0, -6, -2], [19, 1, 1, -7, 9, 2, 1, 9, 11], [-6, 13, -8, 9, 10, 14, 10, 5, -10], [-29, 9, 3, -1, -3, -6, -13, -5, -9], [10, -3, 1, -3, -6, 7, 3, 6, 7], [-31, 5, -7, 5, -9, -8, 3, 9, 1], [-13, -2, 2, 0, -2, 0, 6, 0, -9], [4, -2, -2, -2, -4, 0, 8, 6, -2], [-20, 10, 4, -14, -10, 2, 0, 10, 12], [21, -15, -3, -3, -3, -4, -1, -3, 1], [13, -2, 11, 1, 13, 10, -4, -5, -12], [10, -18, 7, 3, 5, 0, -4, -7, -1], [-2, 10, -2, 2, 6, 0, 6, 8, 0], [30, -12, -1, 1, 7, 10, 4, -3, 3], [15, -13, 5, -9, -7, -6, -3, -5, -1], [-2, 14, -9, -1, -3, 0, 0, 5, -1], [-10, -10, 9, -9, 5, 0, -10, -1, -5], [-14, 12, 6, -10, -6, -18, -16, -4, 0], [2, 14, -2, 8, -2, 0, 2, 4, -2], [4, 10, 3, 3, -13, -12, 0, -5, 3], [2, 16, 8, 8, -2, -10, -14, -16, 0], [-4, 2, 6, -2, 4, 18, -2, -4, 0], [-18, 11, 1, -1, 0, 1, 5, -8, -3], [0, -6, -2, 0, 2, 6, 8, -2, -4], [-24, -4, -4, 6, 2, 12, 8, -12, -2], [26, -4, -2, 6, 2, 2, -6, 0, 0], [-20, 11, -2, -2, 1, -11, -11, -3, 2], [30, -10, 2, -2, 4, 2, 6, -4, 10], [6, -8, 9, -3, -1, -6, 0, 5, -5], [12, 0, 0, 0, 0, 2, 2, -4, 0], [20, -16, 1, 0, -4, -5, 3, 3, 1], [-4, -4, -12, -4, 2, 10, 14, 14, 14], [-22, 16, -8, -6, -10, 0, 2, 8, 4], [-21, -9, -1, -3, 11, 6, -3, 5, -3], [-10, -16, -5, 15, 3, 9, 6, 3, 13], [-24, 8, -6, -4, -12, -4, 6, 16, 6], [-17, -4, -4, 0, 12, 12, -6, -2, -11], [12, -1, 3, 5, -2, 1, 11, 10, 11], [-6, 10, -5, 2, -4, -7, 1, 7, 5], [-20, 7, -5, -3, 8, 5, 1, 2, 3], [10, 4, 8, -4, 2, 4, -8, 4, -10], [-10, 2, -4, 10, 6, 2, 10, -4, -4], [-12, 14, -10, 2, 0, 6, 2, -2, -2], [-16, 2, -2, -4, 12, 14, 6, 2, 0], [34, -14, 9, -1, 5, 4, 2, -5, 3], [-24, 14, -7, 2, -2, 11, 7, 11, 1], [52, -3, 12, 4, 1, -17, -5, -3, 8], [-12, -12, -6, 6, 10, 2, 18, 2, 14], [22, -12, 6, -2, 0, -4, -8, -8, -2], [8, 8, 4, -8, -12, -20, -10, -6, 6], [-16, 12, 1, 3, 9, 10, 8, 7, -9], [20, -10, -4, 14, 12, 12, 14, -4, -6], [-32, 18, 3, 1, 5, 6, -2, -1, 1], [3, 1, -5, -5, 1, 2, -1, 13, 3], [-24, 2, -3, 1, 11, 12, 8, 11, 7], [-28, 12, -4, 0, -4, 8, 12, 12, 14], [30, -15, 9, 1, 8, 1, 1, -6, 1], [10, 4, -8, 2, 0, 16, 6, 10, 0], [18, 10, -1, -1, -1, -6, -4, -5, -7], [-8, 20, -4, 0, -2, -12, -12, 0, 0], [30, 0, 5, 0, 4, 3, -5, 3, -7], [-10, -10, 0, -4, 0, 2, -10, -12, -8], [4, 7, 2, -5, -8, -8, -12, -1, 0], [20, 4, -11, 0, 6, 5, 3, 5, -1], [9, 9, -6, 11, 5, 3, -10, 0, -8], [16, 2, 4, -4, 2, 14, -2, -4, -8], [34, -14, 3, -4, 6, -1, -7, -1, 7], [-6, -12, 12, -4, -2, -12, -10, -16, -6], [-2, -8, -3, 8, 2, 5, -1, -3, 3], [-6, -4, -13, 9, 5, 8, 8, 7, 9], [16, -10, -7, 6, 2, 21, 7, 3, 1], [-14, 6, -9, 10, -6, 1, 1, -3, -1], [32, 4, 11, -6, 0, -5, -3, -5, 1], [6, 16, 0, 8, -4, -5, 6, 6, 2], [-10, 6, 1, -11, -17, -10, -8, 3, 5], [6, 4, 16, -6, -2, -1, -4, -2, 2], [22, -6, 11, -3, -5, -14, -14, -3, 1], [14, 4, -3, 12, 6, 1, -1, 1, -9], [4, -6, -8, -2, 0, -6, 10, 0, 6], [12, -2, 12, -8, -2, -5, -2, -8, 0], [-34, -2, -3, -2, 6, 21, 15, 15, 3], [26, -2, 19, -8, -6, -21, -15, -5, 7], [-20, 4, -4, 0, -6, -2, -4, 8, 8], [10, 18, -2, -4, 2, 12, 4, -4, -6], [25, -7, 6, -6, -14, -4, -17, -18, 2], [45, -4, 6, -10, -2, -4, -8, -10, -3], [20, 10, -2, -2, 6, 10, -4, 8, -6], [-6, -2, 16, 6, 0, -1, 0, 10, -6], [-8, -14, 4, -2, 10, 12, 0, 4, -10], [-10, -7, -13, 11, 0, 11, 7, -4, -3], [12, 8, -11, 7, -1, -2, -4, 5, 1], [0, -4, 8, 0, 4, 4, 4, -6, -8], [-36, -4, -4, 8, -6, -12, 0, -2, -4], [2, 10, 0, -4, -18, -12, -4, -12, 0], [8, 2, -12, 10, 10, 8, 8, 6, -14], [9, 1, 2, -1, 1, 3, 10, -4, 8], [30, 7, 8, -17, -2, -6, -10, -9, -10], [30, 0, 9, 3, 1, -16, -8, -1, -3], [11, -3, 12, 0, 10, 2, 11, -2, 0], [1, 1, -7, 9, -5, -16, -7, -1, -5], [10, -28, -5, -1, 5, 10, 18, 9, 5], [-10, -2, -8, 6, -2, 0, 6, 8, 0]]
